@@ -23,14 +23,4 @@ function shuffleArray(array: unknown[]) {
   }
 }
 
-// Helper type to require one of N keys.
-type RequireOnlyOne<T, Keys extends keyof T = keyof T> = Pick<
-  T,
-  Exclude<keyof T, Keys>
-> &
-  {
-    [K in Keys]?: Required<Pick<T, K>> &
-      Partial<Record<Exclude<Keys, K>, undefined>>;
-  }[Keys];
-
-export {RequireOnlyOne, SocksClientError, shuffleArray};
+export {SocksClientError, shuffleArray};
